Converter
=========

.. currentmodule:: curies

.. autoclass:: Converter
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Converter.bimap

   .. rubric:: Methods Summary

   .. autosummary::

      ~Converter.add_prefix
      ~Converter.add_record
      ~Converter.compress
      ~Converter.compress_or_standardize
      ~Converter.compress_strict
      ~Converter.expand
      ~Converter.expand_all
      ~Converter.expand_or_standardize
      ~Converter.expand_pair
      ~Converter.expand_pair_all
      ~Converter.expand_strict
      ~Converter.file_compress
      ~Converter.file_expand
      ~Converter.format_curie
      ~Converter.from_extended_prefix_map
      ~Converter.from_jsonld
      ~Converter.from_jsonld_github
      ~Converter.from_prefix_map
      ~Converter.from_priority_prefix_map
      ~Converter.from_rdflib
      ~Converter.from_reverse_prefix_map
      ~Converter.from_shacl
      ~Converter.get_prefixes
      ~Converter.get_record
      ~Converter.get_subconverter
      ~Converter.is_curie
      ~Converter.is_uri
      ~Converter.parse_curie
      ~Converter.parse_uri
      ~Converter.pd_compress
      ~Converter.pd_expand
      ~Converter.pd_standardize_curie
      ~Converter.pd_standardize_prefix
      ~Converter.pd_standardize_uri
      ~Converter.standardize_curie
      ~Converter.standardize_prefix
      ~Converter.standardize_uri

   .. rubric:: Attributes Documentation

   .. autoattribute:: bimap

   .. rubric:: Methods Documentation

   .. automethod:: add_prefix
   .. automethod:: add_record
   .. automethod:: compress
   .. automethod:: compress_or_standardize
   .. automethod:: compress_strict
   .. automethod:: expand
   .. automethod:: expand_all
   .. automethod:: expand_or_standardize
   .. automethod:: expand_pair
   .. automethod:: expand_pair_all
   .. automethod:: expand_strict
   .. automethod:: file_compress
   .. automethod:: file_expand
   .. automethod:: format_curie
   .. automethod:: from_extended_prefix_map
   .. automethod:: from_jsonld
   .. automethod:: from_jsonld_github
   .. automethod:: from_prefix_map
   .. automethod:: from_priority_prefix_map
   .. automethod:: from_rdflib
   .. automethod:: from_reverse_prefix_map
   .. automethod:: from_shacl
   .. automethod:: get_prefixes
   .. automethod:: get_record
   .. automethod:: get_subconverter
   .. automethod:: is_curie
   .. automethod:: is_uri
   .. automethod:: parse_curie
   .. automethod:: parse_uri
   .. automethod:: pd_compress
   .. automethod:: pd_expand
   .. automethod:: pd_standardize_curie
   .. automethod:: pd_standardize_prefix
   .. automethod:: pd_standardize_uri
   .. automethod:: standardize_curie
   .. automethod:: standardize_prefix
   .. automethod:: standardize_uri
